Calculate summaries of the reformatted dataset.
Usage
wid_make_summaries(reformat_dir, manifest_dir = NULL, by_sex = FALSE,
cores = parallel::detectCores() - 5)Value
A list with entries for each variable:
typeValue type.missingNumber of missing values across the entire dataset.value_summarySummary of the values, depending on type. For categorical variables, this will be observation counts for each level. For continuous variables, this will be the min, mean, standard deviation, median, and max. For identifier-like variables (character vectors with many unique values), this will be the alphabetically first and last value, and the number of unique values.by_surveyValue summaries within each survey and year which have any observations.